{
  PROCHOOK.H - Copyright (c) 1993 James M. Finnegan, All Rights Reserved
}
unit Prchook;
{
  ProcHook Header.  Used by the ProcHook DLL source files, as well
  as any app using the DLL.

  Added by Michael Hieke:
      See article "Hook and Monitor Any 16-bit Windows Function with Our ProcHook DLL"
      in Microsoft Systems Journal, 1994 Vol. 9, January
      Also on Microsoft Developer Network CD
}

interface

{$IFNDEF WIN32}

uses WinTypes;

type
  NPHookChild = word;
  LPHookChild = ^THookChild;

  NPHookMaster = word;
{$IFDEF USE_HOOKS_EXT}
  LPHookMaster = ^THookMaster;
{$ENDIF}

  PHookChild = ^THookChild;
  THookChild = packed record
    wSig: word;                      { Signature }
    prev: NPHookChild;               { Ptr to previous hook }
    next: NPHookChild;               { Ptr to next hook }
    pHookMaster: NPHookMaster;       { Ptr to master structure }
    cBytes: array[0..4] of byte;     { Bytes of hooked function }
    lpfnNewFunc: TFarProc;           { Ptr to New function }
  end;

{$IFDEF USE_HOOKS_EXT}
  PHookMaster = ^THookMaster;
  THookMaster = packed record
    wSig: word;                      { Signature }
    prev: NPHookMaster;              { Ptr to previous master }
    next: NPHookMaster;              { Ptr to next master }
    head: NPHookChild;               { Ptr to head of child struct }
    tail: NPHookChild;               { Ptr to tail of child struct }
    bExclusive: BOOL;                { Exclusive Hook field }
    wCount: word;                    { Count of # of hooks to this function }
    wUnhookCount: word;              { Count of # of unhooks to this function }
    wDataSel: word;                  { Selector to aliased code selector }
    lpfnHookedFunction: TFarProc;    { Ptr to original function }
  end;
{$ENDIF}

{ API }
function SetProcAddress(lpfnOrigFunc, lpfnNewFunc: TFarProc; bExclusive: BOOL): NPHookChild;
function SetProcRelease(npHookChld: NPHookChild): BOOL;

function ProcHook(npHookChld: NPHookChild): BOOL;
function ProcUnhook(npHookChld: NPHookChild): BOOL;

{$IFDEF USE_HOOKS_EXT}
function GetFirstHMaster(pHookMast: LPHOOKMASTER): NPHookMaster;
function GetNextHMaster(pHookMast: LPHOOKMASTER): NPHookMaster;

function GetFirstHChild(pHookMast: LPHOOKMASTER; pHookChild: LPHookChild): NPHookChild;
function GetNextHChild(pHookChild: LPHookChild): NPHookChild;

function GetOrdFromAddr(hMod: HMODULE; lpfnFuncPtr: TFarProc): word;
function GetNameFromOrd(hMod: HMODULE; wOrdinal: word): PChar;
{$ENDIF}

{$ELSE}
  szError = 'Sorry - only for WIN16...';
{$ENDIF}

implementation

{$IFNDEF WIN32}

const sDLLName = 'PROCHOOK';

function SetProcAddress; external sDLLName;
function SetProcRelease; external sDLLName;

function ProcHook; external sDLLName;
function ProcUnhook; external sDLLName;

{$IFDEF USE_HOOKS_EXT}
function GetFirstHMaster; external sDLLName;
function GetNextHMaster; external sDLLName;

function GetFirstHChild; external sDLLName;
function GetNextHChild; external sDLLName;

function GetOrdFromAddr; external sDLLName;
function GetNameFromOrd; external sDLLName;
{$ENDIF}

{$ENDIF}
begin
end.

